@@ -8,7 +8,10 @@
 @{ */
 
 /** IPv4 address structure. */
-typedef struct { uint8 addr[4]; } ipv4addr;
+typedef struct {
+  /** 32-bit IPv4 address, represented as 4 8-bit \c unsigned \c chars. */
+  uint8 addr[4];
+} ipv4addr;
 /** IPv4 port number. */
 typedef uint16 ipv4port;
 
@@ -16,11 +19,11 @@ extern const ipv4addr IPV4ADDR_ANY;
 extern const ipv4addr IPV4ADDR_BROADCAST;
 extern const ipv4addr IPV4ADDR_LOOPBACK;
 
-extern int ipv4_parse(const char* s, ipv4addr* addr, const char** end);
+extern int ipv4_parse(const char* s, ipv4addr* addr, const char** end) __DEPRECATED__;
 extern const char* ipv4_scan(const char* s, ipv4addr* addr);
 extern const char* ipv4_format(const ipv4addr* addr);
 extern unsigned fmt_ipv4addr(char* buffer, const ipv4addr* addr);
 
-/* @} */
+/** @} */
 
 #endif
